# This file was auto-generated by Fern from our API Definition.

from .address import Address
from .attribute_type import AttributeType
from .attribute_types_response import AttributeTypesResponse
from .attribute_values import AttributeValues
from .attributes_response import AttributesResponse
from .business_purpose import BusinessPurpose
from .count_type import CountType
from .create_resolved_project_entity_request import CreateResolvedProjectEntityRequest
from .facet_bucket import FacetBucket
from .facets_response import FacetsResponse
from .field_match_quality import FieldMatchQuality
from .grouped_attribute import GroupedAttribute
from .grouped_attribute_value import GroupedAttributeValue
from .location import Location
from .match_profile_enum import MatchProfileEnum
from .product_bucket import ProductBucket
from .product_count import ProductCount
from .product_mapping import ProductMapping
from .project_entities_custom_field_filter import ProjectEntitiesCustomFieldFilter
from .project_entities_exact_filter import ProjectEntitiesExactFilter
from .project_entities_filter import ProjectEntitiesFilter
from .project_entities_fuzzy_filter import ProjectEntitiesFuzzyFilter
from .project_entities_response import ProjectEntitiesResponse
from .project_entity_exists_response_data import ProjectEntityExistsResponseData
from .project_entity_id_response import ProjectEntityIdResponse
from .project_entity_match_explanation import ProjectEntityMatchExplanation
from .project_entity_match_response import ProjectEntityMatchResponse
from .project_entity_response import ProjectEntityResponse
from .project_entity_risk_changes_response import ProjectEntityRiskChangesResponse
from .project_entity_risk_changes_response_data import ProjectEntityRiskChangesResponseData
from .project_entity_risk_summary_data import ProjectEntityRiskSummaryData
from .project_entity_risk_summary_filters import ProjectEntityRiskSummaryFilters
from .project_entity_risk_summary_network_path import ProjectEntityRiskSummaryNetworkPath
from .project_entity_risk_summary_response import ProjectEntityRiskSummaryResponse
from .project_entity_risk_summary_response_filters import ProjectEntityRiskSummaryResponseFilters
from .project_entity_risk_summary_risk_factor import ProjectEntityRiskSummaryRiskFactor
from .project_entity_supply_chain_summary_response import ProjectEntitySupplyChainSummaryResponse
from .project_entity_supply_chain_summary_response_data import ProjectEntitySupplyChainSummaryResponseData
from .project_entity_supply_chain_upstream import ProjectEntitySupplyChainUpstream
from .project_risk_category import ProjectRiskCategory
from .project_risk_change import ProjectRiskChange
from .project_risk_changes_response import ProjectRiskChangesResponse
from .project_risk_changes_response_data import ProjectRiskChangesResponseData
from .project_risk_factor import ProjectRiskFactor
from .resolution_attributes import ResolutionAttributes
from .resolution_profile import ResolutionProfile
from .risk_categories_summary import RiskCategoriesSummary
from .risk_change_factor import RiskChangeFactor
from .risk_change_factor_change_type import RiskChangeFactorChangeType
from .risk_change_filters import RiskChangeFilters
from .save_project_entity_body import SaveProjectEntityBody
from .share_information import ShareInformation
from .single_project_entity_response import SingleProjectEntityResponse
from .sort_order import SortOrder
from .source_field import SourceField
from .special_facet_bucket import SpecialFacetBucket
from .special_facets_response import SpecialFacetsResponse
from .string_or_number import StringOrNumber
from .tag_response import TagResponse
from .trade_counts import TradeCounts
from .translation import Translation
from .update_entity_tags_response import UpdateEntityTagsResponse
from .update_project_entity_tags_body import UpdateProjectEntityTagsBody
from .upstream_count import UpstreamCount
from .upstream_info import UpstreamInfo

__all__ = [
    "Address",
    "AttributeType",
    "AttributeTypesResponse",
    "AttributeValues",
    "AttributesResponse",
    "BusinessPurpose",
    "CountType",
    "CreateResolvedProjectEntityRequest",
    "FacetBucket",
    "FacetsResponse",
    "FieldMatchQuality",
    "GroupedAttribute",
    "GroupedAttributeValue",
    "Location",
    "MatchProfileEnum",
    "ProductBucket",
    "ProductCount",
    "ProductMapping",
    "ProjectEntitiesCustomFieldFilter",
    "ProjectEntitiesExactFilter",
    "ProjectEntitiesFilter",
    "ProjectEntitiesFuzzyFilter",
    "ProjectEntitiesResponse",
    "ProjectEntityExistsResponseData",
    "ProjectEntityIdResponse",
    "ProjectEntityMatchExplanation",
    "ProjectEntityMatchResponse",
    "ProjectEntityResponse",
    "ProjectEntityRiskChangesResponse",
    "ProjectEntityRiskChangesResponseData",
    "ProjectEntityRiskSummaryData",
    "ProjectEntityRiskSummaryFilters",
    "ProjectEntityRiskSummaryNetworkPath",
    "ProjectEntityRiskSummaryResponse",
    "ProjectEntityRiskSummaryResponseFilters",
    "ProjectEntityRiskSummaryRiskFactor",
    "ProjectEntitySupplyChainSummaryResponse",
    "ProjectEntitySupplyChainSummaryResponseData",
    "ProjectEntitySupplyChainUpstream",
    "ProjectRiskCategory",
    "ProjectRiskChange",
    "ProjectRiskChangesResponse",
    "ProjectRiskChangesResponseData",
    "ProjectRiskFactor",
    "ResolutionAttributes",
    "ResolutionProfile",
    "RiskCategoriesSummary",
    "RiskChangeFactor",
    "RiskChangeFactorChangeType",
    "RiskChangeFilters",
    "SaveProjectEntityBody",
    "ShareInformation",
    "SingleProjectEntityResponse",
    "SortOrder",
    "SourceField",
    "SpecialFacetBucket",
    "SpecialFacetsResponse",
    "StringOrNumber",
    "TagResponse",
    "TradeCounts",
    "Translation",
    "UpdateEntityTagsResponse",
    "UpdateProjectEntityTagsBody",
    "UpstreamCount",
    "UpstreamInfo",
]



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing
import pydantic


class CreateProjectEntitySupplyChainSnapshotRequest(UniversalBaseModel):
    """
    Examples
    --------
    from sayari.project_entity_supply_chain_snapshots import (
        CreateProjectEntitySupplyChainSnapshotRequest,
    )

    CreateProjectEntitySupplyChainSnapshotRequest(
        label="Q1 2024 Supply Chain Analysis",
    )
    """

    label: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from .ontology_relationships_filters import OntologyRelationshipsFilters
import typing
from .ontology_relationship import OntologyRelationship
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class GetOntologyRelationshipsResponse(UniversalBaseModel):
    """
    Examples
    --------
    from sayari.ontology import (
        GetOntologyRelationshipsResponse,
        OntologyRelationship,
        OntologyRelationshipBetween,
        OntologyRelationshipsFilters,
    )

    GetOntologyRelationshipsResponse(
        filters=OntologyRelationshipsFilters(
            id=["auditor_of"],
        ),
        data=[
            OntologyRelationship(
                id="auditor_of",
                label="Auditor Of",
                description="Companies audited by this entity",
                comment="The source entity is reported to be the auditor of a company",
                type="forward",
                inverse="has_auditor",
                between=[
                    OntologyRelationshipBetween(
                        from_="person",
                        to="company",
                    ),
                    OntologyRelationshipBetween(
                        from_="company",
                        to="company",
                    ),
                ],
                attributes=["additional_information", "position"],
            )
        ],
        total_count=1234,
    )
    """

    filters: OntologyRelationshipsFilters
    data: typing.List[OntologyRelationship]
    total_count: int

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .resolution_response_fields import ResolutionResponseFields
import typing_extensions
import typing
from ...base_types.types.custom_field_value import CustomFieldValue
from ...core.serialization import FieldMetadata
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ResolutionPersistedResponseFields(ResolutionResponseFields):
    custom_field_name: typing_extensions.Annotated[
        typing.Optional[CustomFieldValue], FieldMetadata(alias="custom_{field name}")
    ] = None
    custom_name: typing.Optional[str] = None
    custom_identifier: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from ...generated_types.types.risk_category import RiskCategory

TraversalRiskCategory = typing.Union[typing.List[RiskCategory], str]



# This file was auto-generated by Fern from our API Definition.

import typing
from .environment import SayariEnvironment
import httpx
from .core.oauth_token_provider import OAuthTokenProvider
from .core.client_wrapper import SyncClientWrapper
from .attributes.client import AttributesClient
from .auth.client import AuthClient
from .entity.client import EntityClient
from .info.client import InfoClient
from .metadata.client import MetadataClient
from .negative_news.client import NegativeNewsClient
from .notifications.client import NotificationsClient
from .ontology.client import OntologyClient
from .project_entity_attributes.client import ProjectEntityAttributesClient
from .project_entity_supply_chain_snapshots.client import ProjectEntitySupplyChainSnapshotsClient
from .project_entity.client import ProjectEntityClient
from .project.client import ProjectClient
from .record.client import RecordClient
from .resolution.client import ResolutionClient
from .resource.client import ResourceClient
from .search.client import SearchClient
from .supply_chain.client import SupplyChainClient
from .trade.client import TradeClient
from .traversal.client import TraversalClient
from .core.client_wrapper import AsyncClientWrapper
from .attributes.client import AsyncAttributesClient
from .auth.client import AsyncAuthClient
from .entity.client import AsyncEntityClient
from .info.client import AsyncInfoClient
from .metadata.client import AsyncMetadataClient
from .negative_news.client import AsyncNegativeNewsClient
from .notifications.client import AsyncNotificationsClient
from .ontology.client import AsyncOntologyClient
from .project_entity_attributes.client import AsyncProjectEntityAttributesClient
from .project_entity_supply_chain_snapshots.client import AsyncProjectEntitySupplyChainSnapshotsClient
from .project_entity.client import AsyncProjectEntityClient
from .project.client import AsyncProjectClient
from .record.client import AsyncRecordClient
from .resolution.client import AsyncResolutionClient
from .resource.client import AsyncResourceClient
from .search.client import AsyncSearchClient
from .supply_chain.client import AsyncSupplyChainClient
from .trade.client import AsyncTradeClient
from .traversal.client import AsyncTraversalClient


class BaseClient:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : SayariEnvironment
        The environment to use for requests from the client. from .environment import SayariEnvironment



        Defaults to SayariEnvironment.PRODUCTION



    client_id : str
    client_secret : str
    _token_getter_override : typing.Optional[typing.Callable[[], str]]
    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.Client]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from sayari import Sayari

    client = Sayari(
        client_id="YOUR_CLIENT_ID",
        client_secret="YOUR_CLIENT_SECRET",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: SayariEnvironment = SayariEnvironment.PRODUCTION,
        client_id: str,
        client_secret: str,
        _token_getter_override: typing.Optional[typing.Callable[[], str]] = None,
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.Client] = None,
    ):
        _defaulted_timeout = timeout if timeout is not None else 60 if httpx_client is None else None
        oauth_token_provider = OAuthTokenProvider(
            client_id=client_id,
            client_secret=client_secret,
            client_wrapper=SyncClientWrapper(
                base_url=_get_base_url(base_url=base_url, environment=environment),
                httpx_client=httpx.Client(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
                if follow_redirects is not None
                else httpx.Client(timeout=_defaulted_timeout),
                timeout=_defaulted_timeout,
            ),
        )
        self._client_wrapper = SyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            token=_token_getter_override if _token_getter_override is not None else oauth_token_provider.get_token,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.Client(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.Client(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self.attributes = AttributesClient(client_wrapper=self._client_wrapper)
        self.auth = AuthClient(client_wrapper=self._client_wrapper)
        self.entity = EntityClient(client_wrapper=self._client_wrapper)
        self.info = InfoClient(client_wrapper=self._client_wrapper)
        self.metadata = MetadataClient(client_wrapper=self._client_wrapper)
        self.negative_news = NegativeNewsClient(client_wrapper=self._client_wrapper)
        self.notifications = NotificationsClient(client_wrapper=self._client_wrapper)
        self.ontology = OntologyClient(client_wrapper=self._client_wrapper)
        self.project_entity_attributes = ProjectEntityAttributesClient(client_wrapper=self._client_wrapper)
        self.project_entity_supply_chain_snapshots = ProjectEntitySupplyChainSnapshotsClient(
            client_wrapper=self._client_wrapper
        )
        self.project_entity = ProjectEntityClient(client_wrapper=self._client_wrapper)
        self.project = ProjectClient(client_wrapper=self._client_wrapper)
        self.record = RecordClient(client_wrapper=self._client_wrapper)
        self.resolution = ResolutionClient(client_wrapper=self._client_wrapper)
        self.resource = ResourceClient(client_wrapper=self._client_wrapper)
        self.search = SearchClient(client_wrapper=self._client_wrapper)
        self.supply_chain = SupplyChainClient(client_wrapper=self._client_wrapper)
        self.trade = TradeClient(client_wrapper=self._client_wrapper)
        self.traversal = TraversalClient(client_wrapper=self._client_wrapper)


class AsyncBaseClient:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : SayariEnvironment
        The environment to use for requests from the client. from .environment import SayariEnvironment



        Defaults to SayariEnvironment.PRODUCTION



    client_id : str
    client_secret : str
    _token_getter_override : typing.Optional[typing.Callable[[], str]]
    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.AsyncClient]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from sayari import AsyncSayari

    client = AsyncSayari(
        client_id="YOUR_CLIENT_ID",
        client_secret="YOUR_CLIENT_SECRET",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: SayariEnvironment = SayariEnvironment.PRODUCTION,
        client_id: str,
        client_secret: str,
        _token_getter_override: typing.Optional[typing.Callable[[], str]] = None,
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.AsyncClient] = None,
    ):
        _defaulted_timeout = timeout if timeout is not None else 60 if httpx_client is None else None
        oauth_token_provider = OAuthTokenProvider(
            client_id=client_id,
            client_secret=client_secret,
            client_wrapper=SyncClientWrapper(
                base_url=_get_base_url(base_url=base_url, environment=environment),
                httpx_client=httpx.Client(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
                if follow_redirects is not None
                else httpx.Client(timeout=_defaulted_timeout),
                timeout=_defaulted_timeout,
            ),
        )
        self._client_wrapper = AsyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            token=_token_getter_override if _token_getter_override is not None else oauth_token_provider.get_token,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self.attributes = AsyncAttributesClient(client_wrapper=self._client_wrapper)
        self.auth = AsyncAuthClient(client_wrapper=self._client_wrapper)
        self.entity = AsyncEntityClient(client_wrapper=self._client_wrapper)
        self.info = AsyncInfoClient(client_wrapper=self._client_wrapper)
        self.metadata = AsyncMetadataClient(client_wrapper=self._client_wrapper)
        self.negative_news = AsyncNegativeNewsClient(client_wrapper=self._client_wrapper)
        self.notifications = AsyncNotificationsClient(client_wrapper=self._client_wrapper)
        self.ontology = AsyncOntologyClient(client_wrapper=self._client_wrapper)
        self.project_entity_attributes = AsyncProjectEntityAttributesClient(client_wrapper=self._client_wrapper)
        self.project_entity_supply_chain_snapshots = AsyncProjectEntitySupplyChainSnapshotsClient(
            client_wrapper=self._client_wrapper
        )
        self.project_entity = AsyncProjectEntityClient(client_wrapper=self._client_wrapper)
        self.project = AsyncProjectClient(client_wrapper=self._client_wrapper)
        self.record = AsyncRecordClient(client_wrapper=self._client_wrapper)
        self.resolution = AsyncResolutionClient(client_wrapper=self._client_wrapper)
        self.resource = AsyncResourceClient(client_wrapper=self._client_wrapper)
        self.search = AsyncSearchClient(client_wrapper=self._client_wrapper)
        self.supply_chain = AsyncSupplyChainClient(client_wrapper=self._client_wrapper)
        self.trade = AsyncTradeClient(client_wrapper=self._client_wrapper)
        self.traversal = AsyncTraversalClient(client_wrapper=self._client_wrapper)


def _get_base_url(*, base_url: typing.Optional[str] = None, environment: SayariEnvironment) -> str:
    if base_url is not None:
        return base_url
    elif environment is not None:
        return environment.value
    else:
        raise Exception("Please pass in either base_url or environment to construct the client")



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .project_entity_supply_chain_snapshot_data import ProjectEntitySupplyChainSnapshotData
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ProjectEntitySupplyChainSnapshotsResponse(UniversalBaseModel):
    """
    Examples
    --------
    from sayari.project_entity_supply_chain_snapshots import (
        ProjectEntitySupplyChainSnapshotData,
        ProjectEntitySupplyChainSnapshotsResponse,
    )

    ProjectEntitySupplyChainSnapshotsResponse(
        data=[
            ProjectEntitySupplyChainSnapshotData(
                snapshot_id="xG8wYP",
                label="My REST Snapshot",
                release_tag="20220429212557_test",
                partial_results=False,
                explored_count=6,
                created_at="2025-08-12 20:13:20.49643+00",
                updated_at="2025-08-12 20:13:20.49643+00",
            )
        ],
    )
    """

    data: typing.List[ProjectEntitySupplyChainSnapshotData]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .article import Article
from .negative_news_response import NegativeNewsResponse
from .topics import Topics

__all__ = ["Article", "NegativeNewsResponse", "Topics"]



# This file was auto-generated by Fern from our API Definition.

import typing

RiskCategory = typing.Union[
    typing.Literal[
        "adverse_media",
        "environmental_risk",
        "export_controls",
        "forced_labor",
        "political_exposure",
        "regulatory_action",
        "sanctions",
        "sanctions_and_export_control_lists",
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .supply_chain_node import SupplyChainNode
from .supply_chain_edge import SupplyChainEdge
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ProjectEntitySupplyChainSnapshotDetailData(UniversalBaseModel):
    snapshot_id: str
    label: str
    release_tag: str
    partial_results: bool
    explored_count: int
    created_at: str
    updated_at: str
    nodes: typing.List[SupplyChainNode]
    edges: typing.List[SupplyChainEdge]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from .ontology_identifiers_filters import OntologyIdentifiersFilters
import typing
from .ontology_identifier import OntologyIdentifier
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class GetOntologyIdentifiersResponse(UniversalBaseModel):
    """
    Examples
    --------
    from sayari.ontology import (
        GetOntologyIdentifiersResponse,
        OntologyIdentifier,
        OntologyIdentifiersFilters,
    )

    GetOntologyIdentifiersResponse(
        filters=OntologyIdentifiersFilters(
            id=["aer_free_zone_license"],
        ),
        data=[
            OntologyIdentifier(
                id="aer_free_zone_license",
                label="UAE DAFZ Primary License Number",
                comment="Primary license number of free zone establishment in Dubai",
                regex="^\\d+$",
            )
        ],
        total_count=1234,
    )
    """

    filters: OntologyIdentifiersFilters
    data: typing.List[OntologyIdentifier]
    total_count: int

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from .get_ontology_response_data import GetOntologyResponseData
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing
import pydantic


class GetOntologyResponse(UniversalBaseModel):
    """
    Examples
    --------
    import datetime

    from sayari.ontology import (
        GetOntologyResponse,
        GetOntologyResponseData,
        OntologyAttribute,
        OntologyAttributeField,
        OntologyCountry,
        OntologyCurrency,
        OntologyEntityType,
        OntologyEnum,
        OntologyEnumSymbol,
        OntologyIdentifier,
        OntologyLanguage,
        OntologyRegion,
        OntologyRelationship,
        OntologyRelationshipBetween,
        OntologyRiskFactor,
        OntologySource,
        OntologySourceType,
    )

    GetOntologyResponse(
        data=GetOntologyResponseData(
            attributes=[
                OntologyAttribute(
                    id="additional_information",
                    label="Additional Information",
                    comment="This is a generic attribute used to hold miscellaneous information not covered by any other attribute.",
                    fields=[
                        OntologyAttributeField(
                            id="value",
                            label="Value",
                            comment="The additional information itself",
                            type=["null", "string"],
                        )
                    ],
                )
            ],
            countries=[
                OntologyCountry(
                    id="USA",
                    label="United States",
                    code=13988,
                )
            ],
            currencies=[
                OntologyCurrency(
                    id="USD",
                    label="US Dollar/840/2",
                )
            ],
            entity_types=[
                OntologyEntityType(
                    id="aircraft",
                    label="Aircraft",
                    comment="An airplane, helicopter, or other vehicle that travels by flight",
                    attribute=[
                        "additional_information",
                        "address",
                        "country",
                        "identifier",
                        "measurement",
                        "monetary_value",
                        "name",
                        "risk_intelligence",
                        "weak_identifier",
                    ],
                    relationship=[
                        "generic",
                        "has_owner",
                        "linked_to",
                        "possibly_same_as",
                    ],
                    field=[
                        "additional_information",
                        "address",
                        "country",
                        "generic",
                        "has_owner",
                        "identifier",
                        "linked_to",
                        "measurement",
                        "monetary_value",
                        "name",
                        "possibly_same_as",
                        "risk_intelligence",
                        "weak_identifier",
                    ],
                )
            ],
            enums=[
                OntologyEnum(
                    id="address_type",
                    label="Address Type",
                    comment="This enumerated type indicates the kind of location an address is referring to.",
                    symbols=[
                        OntologyEnumSymbol(
                            id="arrival",
                            label="Arrival",
                            comment="This enumerated type indicates the kind of location an address is referring to.",
                        )
                    ],
                )
            ],
            identifiers=[
                OntologyIdentifier(
                    id="aer_free_zone_license",
                    label="UAE DAFZ Primary License Number",
                    comment="Primary license number of free zone establishment in Dubai",
                    regex="^\\d+$",
                )
            ],
            languages=[
                OntologyLanguage(
                    id="en",
                    label="English",
                )
            ],
            regions=[
                OntologyRegion(
                    id="usa_&_canada",
                    label="Usa & Canada",
                )
            ],
            relationships=[
                OntologyRelationship(
                    id="auditor_of",
                    label="Auditor Of",
                    description="Companies audited by this entity",
                    comment="The source entity is reported to be the auditor of a company",
                    type="forward",
                    inverse="has_auditor",
                    between=[
                        OntologyRelationshipBetween(
                            from_="person",
                            to="company",
                        ),
                        OntologyRelationshipBetween(
                            from_="company",
                            to="company",
                        ),
                    ],
                    attributes=["additional_information", "position"],
                )
            ],
            risk_factors=[
                OntologyRiskFactor(
                    id="psa_owner_of_ofac_fto_sanctioned",
                    categories=["sanctions"],
                    label="Owner of Foreign Terrorist Organisation (May Include 'PSA' Path)",
                    description="This entity possibly owns (minority, majority, or wholly) a Foreign Terrorist Organization up to 3 hops away via direct shareholding relationships with 10% or more controlling interest, including beneficial owner, owner, shareholder, partner, subsidiary, or branch. Applicable to entities globally. This network risk path may include ‘Possibly the Same As’ (PSA) relationships—links between companies or persons that have closely matching attributes across datasets, but do not have enough shared information to definitively establish they are the same entity.",
                    doc="This entity possibly owns (minority, majority, or wholly) a Foreign Terrorist Organization up to 3 hops away via direct shareholding relationships with 10% or more controlling interest, including beneficial owner, owner, shareholder, partner, subsidiary, or branch. Applicable to entities globally. This network risk path may include ‘Possibly the Same As’ (PSA) relationships—links between companies or persons that have closely matching attributes across datasets, but do not have enough shared information to definitively establish they are the same entity.",
                    code=1168016564,
                    level="high",
                    risk_type="network",
                    risk_viz="network",
                    visible=True,
                    enabled=True,
                    type="integer",
                    tg=True,
                    do_not_render_metadata=["traversal_path"],
                )
            ],
            sources=[
                OntologySource(
                    id="e85d865943ee6d8369307569d2ad9de0",
                    label="Acuris Risk Intelligence Adverse Media Data",
                    description="Contains PDFs and URLs to adverse media reporting for PEPs, SOEs, sanctioned entities, and entities linked to financial regulatory and law enforcement actions. Available for millions of entities from 'Acuris Risk Intelligence KYC6 (3rd Party Data)' in 'Records' section.",
                    country="XXX",
                    region="international_(multi-region_coverage)",
                    date_added=datetime.date.fromisoformat(
                        "2022-04-11",
                    ),
                    source_type="adverse_media_/_negative_news_data",
                    record_type="adverse_media_record",
                    structure="unstructured",
                    source_url="https://www.acurisriskintelligence.com/",
                    pep=False,
                    watchlist=False,
                )
            ],
            source_types=[
                OntologySourceType(
                    id="adverse_media_/_negative_news_data",
                    label="Adverse Media / Negative News Data",
                )
            ],
        ),
    )
    """

    data: GetOntologyResponseData

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
from .risk_change_factor_change_type import RiskChangeFactorChangeType
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class RiskChangeFactor(UniversalBaseModel):
    id: str
    timestamp: str = pydantic.Field()
    """
    Timestamp of risk change detection
    """

    change_type: RiskChangeFactorChangeType

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

CountType = typing.Union[typing.Literal["coordinates", "upstream_product_risk", "upstream_product_country"], typing.Any]



# This file was auto-generated by Fern from our API Definition.

from ...core.api_error import ApiError
from ..types.unprocessable_content_response import UnprocessableContentResponse


class UnprocessableContent(ApiError):
    def __init__(self, body: UnprocessableContentResponse):
        super().__init__(status_code=422, body=body)



# This file was auto-generated by Fern from our API Definition.

from .types import (
    TradeTraversalComponent,
    TradeTraversalData,
    TradeTraversalEntity,
    TradeTraversalFilters,
    TradeTraversalPath,
    TradeTraversalPathSegment,
    UpstreamTradeTraversalResponse,
)

__all__ = [
    "TradeTraversalComponent",
    "TradeTraversalData",
    "TradeTraversalEntity",
    "TradeTraversalFilters",
    "TradeTraversalPath",
    "TradeTraversalPathSegment",
    "UpstreamTradeTraversalResponse",
]



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing
import pydantic


class ResolutionUploadResponse(UniversalBaseModel):
    """
    Examples
    --------
    from sayari.resolution import ResolutionUploadResponse

    ResolutionUploadResponse(
        file="vbeck.json",
        uploaded="2024-10-02T20:53:24.007Z",
        count=7,
    )
    """

    file: str
    uploaded: str
    count: int

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from .risk_change_filters import RiskChangeFilters
import typing
from .project_risk_changes_response_data import ProjectRiskChangesResponseData
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ProjectRiskChangesResponse(UniversalBaseModel):
    """
    Examples
    --------
    from sayari.project_entity import (
        ProjectRiskChange,
        ProjectRiskChangesResponse,
        ProjectRiskChangesResponseData,
        RiskChangeFactor,
        RiskChangeFilters,
    )

    ProjectRiskChangesResponse(
        filters=RiskChangeFilters(
            from_="2025-04-20 22:54:00.913586+00",
            to="2025-05-20 22:54:00.913586+00",
        ),
        next="eyJzYXZlZF9yZXNvdXJjZV9pZCI6MSwiZmllbGQiOiJyZWd1bGF0b3J5X2FjdGlvbiIsImRhdGUiOiIyMDIxLTA1LTE5IDAwOjA",
        limit=100,
        data=ProjectRiskChangesResponseData(
            project_id="YVB88Y",
            risk_changes=[
                ProjectRiskChange(
                    project_entity_id="52z4Wa",
                    risk_factors=[
                        RiskChangeFactor(
                            id="pep",
                            timestamp="2025-04-22 22:54:00.913586+00",
                            change_type="added",
                        ),
                        RiskChangeFactor(
                            id="regulatory_action",
                            timestamp="2025-04-22 22:54:00.913586+00",
                            change_type="removed",
                        ),
                    ],
                ),
                ProjectRiskChange(
                    project_entity_id="Gyvp8E",
                    risk_factors=[
                        RiskChangeFactor(
                            id="export_to_sanctioned",
                            timestamp="2025-04-28 22:54:00.913586+00",
                            change_type="added",
                        )
                    ],
                ),
            ],
        ),
    )
    """

    filters: RiskChangeFilters
    next: typing.Optional[str] = None
    prev: typing.Optional[str] = None
    limit: int
    data: ProjectRiskChangesResponseData

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .types import (
    CreateProjectEntitySupplyChainSnapshotRequest,
    CreateProjectEntitySupplyChainSnapshotResponse,
    ProjectEntitySupplyChainSnapshotByIdResponse,
    ProjectEntitySupplyChainSnapshotData,
    ProjectEntitySupplyChainSnapshotDetailData,
    ProjectEntitySupplyChainSnapshotsResponse,
    SupplyChainEdge,
    SupplyChainNode,
)

__all__ = [
    "CreateProjectEntitySupplyChainSnapshotRequest",
    "CreateProjectEntitySupplyChainSnapshotResponse",
    "ProjectEntitySupplyChainSnapshotByIdResponse",
    "ProjectEntitySupplyChainSnapshotData",
    "ProjectEntitySupplyChainSnapshotDetailData",
    "ProjectEntitySupplyChainSnapshotsResponse",
    "SupplyChainEdge",
    "SupplyChainNode",
]



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .project_notification_data import ProjectNotificationData
from ...base_types.types.qualified_count import QualifiedCount
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ProjectNotificationsResponse(UniversalBaseModel):
    """
    OK

    Examples
    --------
    from sayari.base_types import QualifiedCount
    from sayari.notifications import (
        Notification,
        ProjectNotificationData,
        ProjectNotificationRiskData,
        ProjectNotificationsResponse,
    )

    ProjectNotificationsResponse(
        next=False,
        size=QualifiedCount(
            count=73,
            qualifier="eq",
        ),
        data=[
            ProjectNotificationData(
                resource_id="olxQPZ",
                entity_id="IoKwj2-82wwzZRlFA1htGQ",
                notifications=[
                    Notification(
                        type="risk",
                        field="exports_ilab_child_labor",
                        values=["false"],
                        date="2025-06-04T00:00:00.000Z",
                    ),
                    Notification(
                        type="risk",
                        field="exports_ilab_forced_labor",
                        values=["false"],
                        date="2025-06-04T00:00:00.000Z",
                    ),
                    Notification(
                        type="risk",
                        field="forced_labor_xinjiang_origin_subtier",
                        values=["3"],
                        date="2025-06-04T00:00:00.000Z",
                    ),
                    Notification(
                        type="risk",
                        field="psa_exports_ilab_child_labor",
                        values=["false"],
                        date="2025-06-04T00:00:00.000Z",
                    ),
                    Notification(
                        type="risk",
                        field="psa_exports_ilab_forced_labor",
                        values=["false"],
                        date="2025-06-04T00:00:00.000Z",
                    ),
                ],
                custom_fields={},
                risk_notifications=ProjectNotificationRiskData(
                    added=[
                        "exports_ilab_child_labor",
                        "exports_ilab_forced_labor",
                        "psa_exports_ilab_child_labor",
                        "psa_exports_ilab_forced_labor",
                    ],
                    removed=["forced_labor_xinjiang_origin_subtier"],
                    date="2025-06-04T00:00:00.000Z",
                ),
            ),
            ProjectNotificationData(
                resource_id="Kx1w34",
                entity_id="3oKp0fp1UE-W8BG5crAFIw",
                notifications=[
                    Notification(
                        type="risk",
                        field="exports_ilab_child_labor",
                        values=["true"],
                        date="2025-06-04T00:00:00.000Z",
                    ),
                    Notification(
                        type="risk",
                        field="exports_ilab_forced_labor",
                        values=["true"],
                        date="2025-06-04T00:00:00.000Z",
                    ),
                    Notification(
                        type="risk",
                        field="psa_exports_ilab_child_labor",
                        values=["true"],
                        date="2025-06-04T00:00:00.000Z",
                    ),
                    Notification(
                        type="risk",
                        field="psa_exports_ilab_forced_labor",
                        values=["true"],
                        date="2025-06-04T00:00:00.000Z",
                    ),
                ],
                custom_fields={},
                risk_notifications=ProjectNotificationRiskData(
                    added=[],
                    removed=[
                        "exports_ilab_child_labor",
                        "exports_ilab_forced_labor",
                        "psa_exports_ilab_child_labor",
                        "psa_exports_ilab_forced_labor",
                    ],
                    date="2025-06-04T00:00:00.000Z",
                ),
            ),
            ProjectNotificationData(
                resource_id="BOMrB9",
                entity_id="PF0ehzmptuJ2VJr2J5u0nw",
                notifications=[
                    Notification(
                        type="risk",
                        field="export_controls_adjacent",
                        values=["true"],
                        date="2025-06-14T00:00:00.000Z",
                    ),
                    Notification(
                        type="risk",
                        field="exports_bis_high_priority_items_critical_components_indirect",
                        values=["3"],
                        date="2025-06-14T00:00:00.000Z",
                    ),
                ],
                custom_fields={},
                risk_notifications=ProjectNotificationRiskData(
                    added=[
                        "exports_ilab_child_labor",
                        "exports_ilab_forced_labor",
                        "psa_exports_ilab_child_labor",
                        "psa_exports_ilab_forced_labor",
                    ],
                    removed=[
                        "export_controls_adjacent",
                        "exports_bis_high_priority_items_critical_components_indirect",
                        "psa_exports_bis_high_priority_items_critical_components_indirect",
                        "psa_forced_labor_uflpa_origin_subtier",
                        "psa_regulatory_action",
                    ],
                    date="2025-06-04T00:00:00.000Z",
                ),
            ),
        ],
    )
    """

    next: bool
    data: typing.List[ProjectNotificationData]
    size: QualifiedCount

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class ProjectNotificationRiskData(UniversalBaseModel):
    added: typing.List[str] = pydantic.Field()
    """
    The list of fields added
    """

    removed: typing.List[str] = pydantic.Field()
    """
    The list of fields removed
    """

    date: str = pydantic.Field()
    """
    The date of the notification
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .types import (
    GetOntologyAttributesResponse,
    GetOntologyCountriesResponse,
    GetOntologyCurrenciesResponse,
    GetOntologyEntityTypesResponse,
    GetOntologyEnumsResponse,
    GetOntologyHsCodesResponse,
    GetOntologyIdentifiersResponse,
    GetOntologyLanguagesResponse,
    GetOntologyRegionsResponse,
    GetOntologyRelationshipsResponse,
    GetOntologyResponse,
    GetOntologyResponseData,
    GetOntologyRiskFactorsResponse,
    GetOntologySourceTypesResponse,
    GetOntologySourcesResponse,
    OntologyAttribute,
    OntologyAttributeField,
    OntologyAttributesFilters,
    OntologyBaseFilters,
    OntologyCountriesFilters,
    OntologyCountry,
    OntologyCurrenciesFilters,
    OntologyCurrency,
    OntologyEntityType,
    OntologyEntityTypeField,
    OntologyEntityTypesFilters,
    OntologyEnum,
    OntologyEnumSymbol,
    OntologyHsCode,
    OntologyHsCodesFilters,
    OntologyIdentifier,
    OntologyIdentifiersFilters,
    OntologyLanguage,
    OntologyLanguagesFilters,
    OntologyRegion,
    OntologyRelationship,
    OntologyRelationshipBetween,
    OntologyRelationshipsFilters,
    OntologyRiskFactor,
    OntologyRiskFactorsFilters,
    OntologySource,
    OntologySourceType,
    OntologySourcesFilters,
)

__all__ = [
    "GetOntologyAttributesResponse",
    "GetOntologyCountriesResponse",
    "GetOntologyCurrenciesResponse",
    "GetOntologyEntityTypesResponse",
    "GetOntologyEnumsResponse",
    "GetOntologyHsCodesResponse",
    "GetOntologyIdentifiersResponse",
    "GetOntologyLanguagesResponse",
    "GetOntologyRegionsResponse",
    "GetOntologyRelationshipsResponse",
    "GetOntologyResponse",
    "GetOntologyResponseData",
    "GetOntologyRiskFactorsResponse",
    "GetOntologySourceTypesResponse",
    "GetOntologySourcesResponse",
    "OntologyAttribute",
    "OntologyAttributeField",
    "OntologyAttributesFilters",
    "OntologyBaseFilters",
    "OntologyCountriesFilters",
    "OntologyCountry",
    "OntologyCurrenciesFilters",
    "OntologyCurrency",
    "OntologyEntityType",
    "OntologyEntityTypeField",
    "OntologyEntityTypesFilters",
    "OntologyEnum",
    "OntologyEnumSymbol",
    "OntologyHsCode",
    "OntologyHsCodesFilters",
    "OntologyIdentifier",
    "OntologyIdentifiersFilters",
    "OntologyLanguage",
    "OntologyLanguagesFilters",
    "OntologyRegion",
    "OntologyRelationship",
    "OntologyRelationshipBetween",
    "OntologyRelationshipsFilters",
    "OntologyRiskFactor",
    "OntologyRiskFactorsFilters",
    "OntologySource",
    "OntologySourceType",
    "OntologySourcesFilters",
]



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from .ontology_languages_filters import OntologyLanguagesFilters
import typing
from .ontology_language import OntologyLanguage
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class GetOntologyLanguagesResponse(UniversalBaseModel):
    """
    Examples
    --------
    from sayari.ontology import (
        GetOntologyLanguagesResponse,
        OntologyLanguage,
        OntologyLanguagesFilters,
    )

    GetOntologyLanguagesResponse(
        filters=OntologyLanguagesFilters(
            id=["en"],
        ),
        data=[
            OntologyLanguage(
                id="en",
                label="English",
            )
        ],
        total_count=1234,
    )
    """

    filters: OntologyLanguagesFilters
    data: typing.List[OntologyLanguage]
    total_count: int

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .project_entity_attribute import ProjectEntityAttribute
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ProjectEntityAttributesResponse(UniversalBaseModel):
    """
    Examples
    --------
    from sayari.project_entity_attributes import (
        ProjectEntityAttribute,
        ProjectEntityAttributesResponse,
        ProjectEntityAttributeValue,
    )

    ProjectEntityAttributesResponse(
        data=[
            ProjectEntityAttribute(
                field="name",
                match_resolution=True,
                values=[
                    ProjectEntityAttributeValue(
                        id=1,
                        value="Example Company",
                    ),
                    ProjectEntityAttributeValue(
                        id=2,
                        value="Updated Company Name",
                    ),
                ],
            ),
            ProjectEntityAttribute(
                field="custom_address",
                match_resolution=False,
                values=[
                    ProjectEntityAttributeValue(
                        id=3,
                        value="123 Main Street",
                    ),
                    ProjectEntityAttributeValue(
                        id=4,
                        value="456 Oak Avenue",
                    ),
                ],
            ),
        ],
    )
    """

    data: typing.List[ProjectEntityAttribute]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import enum


class SayariEnvironment(enum.Enum):
    PRODUCTION = "https://api.sayari.com"
    """
    Sayari production - the default environment
    """

    DEV = "https://api.internal.sayari.com"
    """
    Sayari development - utilized for internal testing before promotion to production
    """

    PRODUCTION_UK = "https://api.uk.sayari.com"
    """
    Sayari production - UK environment
    """



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from ...generated_types.types.risk import Risk
import pydantic
from ...generated_types.types.country import Country
import typing_extensions
from ...core.serialization import FieldMetadata
from .project_entities_fuzzy_filter import ProjectEntitiesFuzzyFilter
from .project_entities_exact_filter import ProjectEntitiesExactFilter
from ...generated_types.types.company_status import CompanyStatus
from ...shared_types.types.case_status import CaseStatus
from ...shared_types.types.match_strength_enum import MatchStrengthEnum
from ...shared_types.types.match_count import MatchCount
from .project_entities_custom_field_filter import ProjectEntitiesCustomFieldFilter
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class ProjectEntitiesFilter(UniversalBaseModel):
    risk_factor: typing.Optional[typing.List[Risk]] = pydantic.Field(default=None)
    """
    Filter by [risk factor](/sayari-library/ontology/risk-factors) ID.
    """

    risk_category: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Filter by risk factor `category`, e.g. `sanctions`. At least one risk factor from each provided category must be present.
    """

    upstream_product: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Filter by upstream (supply chain) product ID.
    """

    shipment_country: typing.Optional[typing.List[Country]] = pydantic.Field(default=None)
    """
    Filter by upstream (supply chain) [country](/sayari-library/ontology/enumerated-types#country) at any tier.
    """

    tier_1_shipment_country: typing_extensions.Annotated[
        typing.Optional[typing.List[Country]], FieldMetadata(alias="tier1_shipment_country")
    ] = pydantic.Field(default=None)
    """
    Filter by upstream (supply chain) [country](/sayari-library/ontology/enumerated-types#country) at tier 1.
    """

    tier_2_shipment_country: typing_extensions.Annotated[
        typing.Optional[typing.List[Country]], FieldMetadata(alias="tier2_shipment_country")
    ] = pydantic.Field(default=None)
    """
    Filter by upstream (supply chain) [country](/sayari-library/ontology/enumerated-types#country) at tier 2.
    """

    tier_3_shipment_country: typing_extensions.Annotated[
        typing.Optional[typing.List[Country]], FieldMetadata(alias="tier3_shipment_country")
    ] = pydantic.Field(default=None)
    """
    Filter by upstream (supply chain) [country](/sayari-library/ontology/enumerated-types#country) at tier 3.
    """

    tier_4_shipment_country: typing_extensions.Annotated[
        typing.Optional[typing.List[Country]], FieldMetadata(alias="tier4_shipment_country")
    ] = pydantic.Field(default=None)
    """
    Filter by upstream (supply chain) [country](/sayari-library/ontology/enumerated-types#country) at tier 4.
    """

    tier_5_shipment_country: typing_extensions.Annotated[
        typing.Optional[typing.List[Country]], FieldMetadata(alias="tier5_shipment_country")
    ] = pydantic.Field(default=None)
    """
    Filter by upstream (supply chain) [country](/sayari-library/ontology/enumerated-types#country) at tier 5.
    """

    country: typing.Optional[typing.List[Country]] = pydantic.Field(default=None)
    """
    Filter by [country](/sayari-library/ontology/enumerated-types#country).
    """

    business_purpose: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Filter by HS code, HS code description, or business description.
    """

    label: typing.Optional[ProjectEntitiesFuzzyFilter] = pydantic.Field(default=None)
    """
    Filter by entity label with fuzzy matching.
    """

    city: typing.Optional[ProjectEntitiesFuzzyFilter] = pydantic.Field(default=None)
    """
    Filter by entity city with fuzzy matching.
    """

    state: typing.Optional[ProjectEntitiesFuzzyFilter] = pydantic.Field(default=None)
    """
    Filter by entity address state with fuzzy matching.
    """

    identifier: typing.Optional[ProjectEntitiesFuzzyFilter] = pydantic.Field(default=None)
    """
    Filter by entity identifier attributes with fuzzy matching.
    """

    source: typing.Optional[ProjectEntitiesExactFilter] = pydantic.Field(default=None)
    """
    Filter by entity source ID.
    """

    status: typing.Optional[typing.List[CompanyStatus]] = pydantic.Field(default=None)
    """
    Filter by entity [company status](/sayari-library/ontology/enumerated-types#company-status).
    """

    bounds: typing.Optional[str] = pydantic.Field(default=None)
    """
    Filter by a geographical bounding box. The value is a pipe-delimited set of four values representing the top, left, bottom, and right sides of the bounding box, in that order. The pipes should be URL-encoded as `%7C`. The top coordinate must greater than the bottom coordinate, and the left coordinate must be less than the right coordinate. A sample is `55.680357237879136|-71.53607290158526|41.10876347746233|-40.963927098414736`
    """

    match_entity_id: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Filter by match entity ID.
    """

    entity_type: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Filter by entity type.
    """

    tag: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Filter by tag ID.
    """

    upload: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Filter by upload ID.
    """

    case_status: typing.Optional[typing.List[CaseStatus]] = pydantic.Field(default=None)
    """
    Filter by case status.
    """

    match_strength: typing.Optional[typing.List[MatchStrengthEnum]] = pydantic.Field(default=None)
    """
    Filter by match strength.
    """

    match_count: typing.Optional[MatchCount] = pydantic.Field(default=None)
    """
    Filter by match count.
    """

    attribute: typing.Optional[ProjectEntitiesCustomFieldFilter] = pydantic.Field(default=None)
    """
    Filter by custom field.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from .ontology_entity_types_filters import OntologyEntityTypesFilters
import typing
from .ontology_entity_type import OntologyEntityType
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class GetOntologyEntityTypesResponse(UniversalBaseModel):
    """
    Examples
    --------
    from sayari.ontology import (
        GetOntologyEntityTypesResponse,
        OntologyEntityType,
        OntologyEntityTypesFilters,
    )

    GetOntologyEntityTypesResponse(
        filters=OntologyEntityTypesFilters(
            id=["aircraft"],
        ),
        data=[
            OntologyEntityType(
                id="aircraft",
                label="Aircraft",
                comment="An airplane, helicopter, or other vehicle that travels by flight",
                attribute=[
                    "additional_information",
                    "address",
                    "country",
                    "identifier",
                    "measurement",
                    "monetary_value",
                    "name",
                    "risk_intelligence",
                    "weak_identifier",
                ],
                relationship=[
                    "generic",
                    "has_owner",
                    "linked_to",
                    "possibly_same_as",
                ],
                field=[
                    "additional_information",
                    "address",
                    "country",
                    "generic",
                    "has_owner",
                    "identifier",
                    "linked_to",
                    "measurement",
                    "monetary_value",
                    "name",
                    "possibly_same_as",
                    "risk_intelligence",
                    "weak_identifier",
                ],
            )
        ],
        total_count=1234,
    )
    """

    filters: OntologyEntityTypesFilters
    data: typing.List[OntologyEntityType]
    total_count: int

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from ...generated_types.types.country import Country
from .risk_categories_summary import RiskCategoriesSummary
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ProjectEntitySupplyChainUpstream(UniversalBaseModel):
    components: typing.List[str]
    countries: typing.List[Country]
    risk_categories: typing.List[RiskCategoriesSummary]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
